#===============================================================================
# GNU LESSER GENERAL PUBLIC LICENSE
#===============================================================================
# This source file is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation; either version 2.1 of the License, or (at your
# option) any later version. This source is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Lesser General Public License for more details. You should have
# received a copy of the GNU Lesser General Public License along with this
# source; if not, download it from http://www.gnu.org/licenses/lgpl-2.1.html
#===============================================================================
# Qiang Du <du.qiang@gmail.com>
# 01/07/2015

import etherbone as eb
import sys
import logging

class EB:
    """ access a Etherbone device. """

    def __init__(self, ip):
        """ Initialize EB class.
        ip  -- IP address of Etherbone device
        """
        self.port_ip = 'udp/' + ip
        self.write_cnt = 0
        self.read_cnt = 0

    def open(self):
        self.socket = eb.Socket()
        self.socket.__enter__()

        self.device = eb.Device(self.socket, self.port_ip)
        self.device.__enter__()

    def close(self):
        self.device.close()
        self.socket.close()

    def write(self, addr, val):
        logging.debug('write:   0x%08x'% val)
        self.device.write(addr, val)

    def read(self, addr):
        val = self.device.read(addr)
        logging.debug('read:    0x%08x'% val)
        return val
"""
    def writemregs(self, addr, dlist):
        with eb.Cycle(self.device, 0, 0) as cycle:
            for v in dlist:
                cycle.write(addr, v)
                logging.debug('mwrite:  0x%08x'% v)

    def readmregs(self, addr, nrregs):
        with eb.Cycle(self.device, 0, 0) as cycle:
            dlist = cycle.read(addr, nrregs)
        return dlist
"""
