import os
import sys,getopt
import time
import struct
import logging
sys.path.append("eb")
from eb import *
from xil_multiboot import *


def usage():
    print 'usage: mbtest.py [commands]'
    print '-t, --target <ip address>'
    print '-h, --help'
    print '-a, --address <address in hex>'
    print '-d, --dump <filename>'
    print '-p, --program <filename>'
    print '-e, --erase <size in hex (min 64kB)>'
    print '-i, --id'
    print '-s, --status'
    print '-r, --reconfigure <address in hex>'

def main(argv):
    log_level = logging.DEBUG
    log_level = logging.INFO
    logging.basicConfig(level=log_level)

    if len(argv)==0:
        usage()
        sys.exit()

    try:
        opts, args = getopt.getopt(argv, 'hisa:d:p:e:t:r:',['help','dump=','target=','address=','program=','erase=','id','status','reconfigure='])
    except getopt.GetoptError as err:
        print str(err)
        sys.exit(2)

    baseaddr = 0x20800
    target_ip = 'rflab2.lbl.gov'
    flash_address = 0x0
    flash_size = 0xf3
    prog_file = '../../syn/cute_wr/wr_core_demo/cute_top_wrc.bin'
    dump_file = 'dump_foo'

    for opt,arg in opts:
        if opt in ('-h', '--help'):
            usage()
            sys.exit()
        elif opt in ('--dump', '-d'):
            dump_file=arg
            action = 'dump'
        elif opt in ('-t', '--target'):
            target_ip = arg
            print 'target',target_ip
        elif opt in ('-a', '--address'):
            flash_address = int(arg, base=16)
            print 'address: ',flash_address
        elif opt in ('--program', '-p'):
            prog_file = arg
            fileinfo = os.stat(prog_file)
            flash_size = fileinfo.st_size
            action = 'program'
        elif opt in ('--erase', '-e'):
            flash_size = int(arg, base=16)
            action = 'serase'
        elif opt in ('--id', '-i'):
            action = 'id'
        elif opt in ('--status', '-s'):
            action = 'status'
        elif opt in ('--reconfigure', '-r'):
            action = 'reconfigure'
            icap_addr = int(arg, base=16)

    logging.info('action ='+ action)

    target = EB(target_ip)
    target.open()
    mb = XilMultiboot(ETHERBONE, target, baseaddr, prog_file)

    if (action is 'program'):
        logging.info('Programming file %s'% prog_file)
        mb.write(flash_address)
    elif (action is 'serase'):
        mb.flash.serase(flash_address)
    elif (action is 'id'):
        flash_id = mb.flash.read_id()
        logging.info('Flash ID:    0x' + flash_id.encode('hex'))
    elif (action is 'dump'):
        logging.info('Dumping to file %s from address 0x%x to 0x%x'%(dump_file, flash_address, flash_address+flash_size))
        mb.read(dump_file, flash_address,flash_address+flash_size)
        #mb.dump(dump_file, flash_address,flash_address+flash_size)
    elif (action is 'status'):
        status = mb.flash.rsr()
        logging.info('Status:    0x%x'% status)
    elif (action is 'reconfigure'):
        logging.info('reconfiguring to add: 0x%x' % icap_addr)
        mb.iprog(icap_addr)

    target.close()

if __name__ == "__main__":
    main(sys.argv[1:])
